==> kommando_0.4.1.orig.tar.gz: kommando-0.4.1.orig/src/servicemenu.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Sergio Cambra                                   *
 *   runico@users.berlios.de                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef SERVICEMENU_H
#define SERVICEMENU_H

#include <kpopupmenu.h>
#include <ksycocaentry.h>
#include <kservice.h>

/**
@author Sergio Cambra
 */
class ServiceMenu : public KPopupMenu
{
Q_OBJECT
public:
	ServiceMenu(QObject *receiver, const char *slotActivated,
				QWidget *parent = 0, const char *name = 0);
	ServiceMenu(const QString & relPath, QObject *receiver, const char *slotActivated,
				QWidget *parent = 0, const char *name = 0);

    ~ServiceMenu();

signals:
	void serviceSelected(KService*);
	
protected slots:
	void createMenu();
	void slotActivated(int id);

private:
	QString m_relPath;
	QPtrList<QPopupMenu> m_subMenus;
	QMap<int, KSycocaEntry::Ptr> m_entryMap;
	QObject *m_receiver;
	const char *m_slotActivated;
	
	void initialize();
	void insertMenuItem(KService::Ptr &s, const QStringList *suppressGenericNames = 0);
};

#endif

==> kommando_0.5.1.orig.tar.gz: kommando-0.5.1.orig/src/servicemenu.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Sergio Cambra                                   *
 *   runico@users.berlios.de                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef SERVICEMENU_H
#define SERVICEMENU_H

#include <kpopupmenu.h>
#include <ksycocaentry.h>
#include <kservice.h>

class KServiceGroup;

/**
@author Sergio Cambra
 */
class ServiceMenu : public KPopupMenu
{
Q_OBJECT
public:
    ServiceMenu(QObject *receiver, const char *slotActivatedItem,
                const char *slotActivatedGroup, QWidget *parent = 0, const char *name = 0);
    ServiceMenu(const QString & relPath, QObject *receiver, const char *slotActivatedItem,
                const char *slotActivatedGroup, QWidget *parent = 0, const char *name = 0);

    ~ServiceMenu();

signals:
	void serviceSelected(KService*);
    void serviceGroupSelected(KServiceGroup*);
	
protected slots:
	void createMenu();
	void slotActivated(int id);

private:
    QIconSet getIconSet(const QString& icon) const;
	QString m_relPath;
	QPtrList<QPopupMenu> m_subMenus;
	QMap<int, KSycocaEntry::Ptr> m_entryMap;
	QObject *m_receiver;
	const char *m_slotActivatedItem;
    const char *m_slotActivatedGroup;
	
	void initialize();
	void insertMenuItem(KService::Ptr &s, const QStringList *suppressGenericNames = 0);
};

#endif
